@@ -60,20 +60,20 @@ private Q_SLOTS:
 
         const auto dt = QDateTime::currentDateTimeUtc();
 
-        TimelineElement group(TimelineElement::TripGroup, dt);
+        TimelineElement group(nullptr, TimelineElement::TripGroup, dt);
         group.rangeType = TimelineElement::RangeBegin;
-        QTest::newRow("transfer-group-begin") << group << TimelineElement(TimelineElement::Transfer, dt);
+        QTest::newRow("transfer-group-begin") << group << TimelineElement(nullptr, TimelineElement::Transfer, dt);
         group.rangeType = TimelineElement::RangeEnd;
-        QTest::newRow("transfer-group-end") << TimelineElement(TimelineElement::Transfer, dt) << group;
+        QTest::newRow("transfer-group-end") << TimelineElement(nullptr, TimelineElement::Transfer, dt) << group;
 
-        TimelineElement locInfo(TimelineElement::LocationInfo, dt);
-        TimelineElement hotel(TimelineElement::Hotel, dt);
+        TimelineElement locInfo(nullptr, TimelineElement::LocationInfo, dt);
+        TimelineElement hotel(nullptr, TimelineElement::Hotel, dt);
         hotel.rangeType = TimelineElement::RangeBegin;
         QTest::newRow("locinfo-before-hotel") << locInfo << hotel;
-        TimelineElement flight(TimelineElement::Flight, dt);
+        TimelineElement flight(nullptr, TimelineElement::Flight, dt);
         QTest::newRow("locinfo-before-flight") << locInfo << flight;
 
-        QTest::newRow("location-info-before-transfer") << TimelineElement(TimelineElement::LocationInfo, dt) << TimelineElement(TimelineElement::Transfer, dt);
+        QTest::newRow("location-info-before-transfer") << TimelineElement(nullptr, TimelineElement::LocationInfo, dt) << TimelineElement(nullptr, TimelineElement::Transfer, dt);
     }
 
     void testElementCompare()
@@ -90,9 +90,9 @@ private Q_SLOTS:
         Test::clearAll(&mgr);
         ReservationManager resMgr;
         Test::clearAll(&resMgr);
-        ApplicationController ctrl;
-        ctrl.setPkPassManager(&mgr);
-        ctrl.setReservationManager(&resMgr);
+        auto ctrl = Test::makeAppController();
+        ctrl->setPkPassManager(&mgr);
+        ctrl->setReservationManager(&resMgr);
 
         TimelineModel model;
         QAbstractItemModelTester tester(&model);
@@ -107,7 +107,7 @@ private Q_SLOTS:
 
         QCOMPARE(model.rowCount(), 1);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
-        mgr.importPass(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/boardingpass-v1.pkpass")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/boardingpass-v1.pkpass")));
         QCOMPARE(insertSpy.size(), 1);
         QCOMPARE(insertSpy.at(0).at(1).toInt(), 0);
         QCOMPARE(insertSpy.at(0).at(2).toInt(), 0);
@@ -115,7 +115,7 @@ private Q_SLOTS:
         QCOMPARE(model.rowCount(), 2);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
 
-        mgr.importPass(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/boardingpass-v2.pkpass")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/boardingpass-v2.pkpass")));
         QCOMPARE(insertSpy.size(), 1);
         QCOMPARE(updateSpy.size(), 1);
         QCOMPARE(updateSpy.at(0).at(0).toModelIndex().row(), 0);
@@ -132,8 +132,8 @@ private Q_SLOTS:
     {
         ReservationManager resMgr;
         Test::clearAll(&resMgr);
-        ApplicationController ctrl;
-        ctrl.setReservationManager(&resMgr);
+        auto ctrl = Test::makeAppController();
+        ctrl->setReservationManager(&resMgr);
 
         TimelineModel model;
         QAbstractItemModelTester tester(&model);
@@ -149,7 +149,7 @@ private Q_SLOTS:
 
         QCOMPARE(model.rowCount(), 1);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
-        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/haus-randa-v1.json")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/haus-randa-v1.json")));
         QCOMPARE(insertSpy.size(), 3);
         QCOMPARE(insertSpy.at(0).at(1).toInt(), 0);
         QCOMPARE(insertSpy.at(0).at(2).toInt(), 0);
@@ -164,7 +164,7 @@ private Q_SLOTS:
         QCOMPARE(model.index(2, 0).data(TimelineModel::ElementRangeRole), TimelineElement::RangeEnd);
 
         // move end date of a hotel booking: dataChanged on RangeBegin, move (or del/ins) on RangeEnd
-        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/haus-randa-v2.json")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/haus-randa-v2.json")));
         QCOMPARE(insertSpy.size(), 5);
         QCOMPARE(updateSpy.size(), 1);
         QCOMPARE(rmSpy.size(), 2);
@@ -187,8 +187,8 @@ private Q_SLOTS:
     {
         ReservationManager resMgr;
         Test::clearAll(&resMgr);
-        ApplicationController ctrl;
-        ctrl.setReservationManager(&resMgr);
+        auto ctrl = Test::makeAppController();
+        ctrl->setReservationManager(&resMgr);
 
         TimelineModel model;
         QAbstractItemModelTester tester(&model);
@@ -198,7 +198,7 @@ private Q_SLOTS:
         QCOMPARE(model.rowCount(), 1);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
 
-        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
         QCOMPARE(model.rowCount(), 5); //  2x country info, 2x flights, today marker
 
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
@@ -389,8 +389,8 @@ private Q_SLOTS:
 
         ReservationManager resMgr;
         Test::clearAll(&resMgr);
-        ApplicationController ctrl;
-        ctrl.setReservationManager(&resMgr);
+        auto ctrl = Test::makeAppController();
+        ctrl->setReservationManager(&resMgr);
         TimelineModel model;
         QAbstractItemModelTester tester(&model);
         model.setReservationManager(&resMgr);
@@ -404,7 +404,7 @@ private Q_SLOTS:
         QVERIFY(rmSpy.isValid());
 
         // full import at runtime
-        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/google-multi-passenger-flight.json")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/google-multi-passenger-flight.json")));
         QCOMPARE(model.rowCount(), 3); // 2x Flight, 1x TodayMarger
         QCOMPARE(insertSpy.count(), 2);
         QCOMPARE(updateSpy.count(), 2);
@@ -464,8 +464,8 @@ private Q_SLOTS:
     {
         ReservationManager resMgr;
         Test::clearAll(&resMgr);
-        ApplicationController ctrl;
-        ctrl.setReservationManager(&resMgr);
+        auto ctrl = Test::makeAppController();
+        ctrl->setReservationManager(&resMgr);
         WeatherForecastManager weatherMgr;
         weatherMgr.setTestModeEnabled(true);
 
@@ -487,7 +487,7 @@ private Q_SLOTS:
         QVERIFY(vp1.verify(&model));
 
         // load something to define the current location, so we get weather
-        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
         ModelVerificationPoint vp2(QLatin1String(SOURCE_DIR "/data/timeline/daychange-r2.model"));
         vp2.setRoleFilter({TimelineModel::BatchIdRole});
         QVERIFY(vp2.verify(&model));
@@ -516,9 +516,9 @@ private Q_SLOTS:
         QFETCH(QString, baseName);
         ReservationManager resMgr;
         Test::clearAll(&resMgr);
-        ApplicationController ctrl;
-        ctrl.setReservationManager(&resMgr);
-        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/timeline/") + baseName + QLatin1String(".json")));
+        auto ctrl = Test::makeAppController();
+        ctrl->setReservationManager(&resMgr);
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/timeline/") + baseName + QLatin1String(".json")));
         TripGroupManager groupMgr;
         groupMgr.setReservationManager(&resMgr);
         WeatherForecastManager weatherMgr;
@@ -559,7 +559,7 @@ private Q_SLOTS:
 
         // retry with loading during runtime
         Test::clearAll(&resMgr);
-        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/timeline/") + baseName + QLatin1String(".json")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/timeline/") + baseName + QLatin1String(".json")));
         QVERIFY(vp.verify(&model));
     }
 
@@ -567,8 +567,8 @@ private Q_SLOTS:
     {
         ReservationManager resMgr;
         Test::clearAll(&resMgr);
-        ApplicationController ctrl;
-        ctrl.setReservationManager(&resMgr);
+        auto ctrl = Test::makeAppController();
+        ctrl->setReservationManager(&resMgr);
 
         TimelineModel model;
         model.setCurrentDateTime(QDateTime({2017, 8, 1}, {23, 0}, QTimeZone("Europe/Zurich")));
@@ -577,7 +577,7 @@ private Q_SLOTS:
 
         QSignalSpy currentResChangedSpy(&model, &TimelineModel::currentBatchChanged);
 
-        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/../tests/randa2017.json")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/../tests/randa2017.json")));
         QCOMPARE(model.rowCount(), 13);
         QVERIFY(!currentResChangedSpy.empty());
 
