@@ -21,7 +21,6 @@
 #include <QFile>
 #include <QGuiApplication>
 #include <QUrl>
-#include <QSortFilterProxyModel>
 
 int main(int argc, char **argv)
 {
@@ -29,8 +28,10 @@ int main(int argc, char **argv)
     QCoreApplication::setOrganizationName(QStringLiteral("KDE"));
     QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
     QGuiApplication app(argc, argv);
 
     QCommandLineParser parser;
@@ -57,7 +58,6 @@ int main(int argc, char **argv)
     req.setTo(to);
     req.setIncludeIntermediateStops(true);
 
-    qmlRegisterType<QSortFilterProxyModel>("org.kde.itinerary", 1, 0, "SortFilterProxyModel");
     qmlRegisterSingletonType("org.kde.itinerary", 1, 0, "Localizer", [](QQmlEngine*, QJSEngine *engine) -> QJSValue {
         return engine->toScriptValue(Localizer());
     });
